@@ -55,12 +55,7 @@ from django.contrib.auth.models import Group, Permission
 from django.core.cache import cache
 from django.core.exceptions import ImproperlyConfigured, ObjectDoesNotExist
 
-from django_auth_ldap.config import (
-    ConfigurationWarning,
-    LDAPGroupQuery,
-    LDAPSearch,
-    _LDAPConfig,
-)
+from .config import ConfigurationWarning, LDAPGroupQuery, LDAPSearch, _LDAPConfig
 
 logger = _LDAPConfig.get_logger()
 
@@ -146,7 +141,7 @@ class LDAPBackend:
             ldap_user = _LDAPUser(self, username=username.strip(), request=request)
             user = self.authenticate_ldap_user(ldap_user, password)
         else:
-            logger.debug("Rejecting empty password for {}".format(username))
+            logger.debug("Rejecting empty password for %s", username)
             user = None
 
         return user
@@ -350,7 +345,7 @@ class _LDAPUser:
 
             user = self._user
         except self.AuthenticationFailed as e:
-            logger.debug("Authentication failed for {}: {}".format(self._username, e))
+            logger.debug("Authentication failed for %s: %s", self._username, e)
         except ldap.LDAPError as e:
             results = ldap_error.send(
                 type(self.backend),
@@ -361,12 +356,12 @@ class _LDAPUser:
             )
             if len(results) == 0:
                 logger.warning(
-                    "Caught LDAPError while authenticating {}: {}".format(
-                        self._username, pprint.pformat(e)
-                    )
+                    "Caught LDAPError while authenticating %s: %s",
+                    self._username,
+                    pprint.pformat(e),
                 )
         except Exception as e:
-            logger.warning("{} while authenticating {}".format(e, self._username))
+            logger.warning("%s while authenticating %s", e, self._username)
             raise
 
         return user
@@ -393,9 +388,8 @@ class _LDAPUser:
                     )
                     if len(results) == 0:
                         logger.warning(
-                            "Caught LDAPError loading group permissions: {}".format(
-                                pprint.pformat(e)
-                            )
+                            "Caught LDAPError loading group permissions: %s",
+                            pprint.pformat(e),
                         )
 
         return self._group_permissions
@@ -423,12 +417,12 @@ class _LDAPUser:
             )
             if len(results) == 0:
                 logger.warning(
-                    "Caught LDAPError while authenticating {}: {}".format(
-                        self._username, pprint.pformat(e)
-                    )
+                    "Caught LDAPError while authenticating %s: %s",
+                    self._username,
+                    pprint.pformat(e),
                 )
         except Exception as e:
-            logger.warning("{} while authenticating {}".format(e, self._username))
+            logger.warning("%s while authenticating %s", e, self._username)
             raise
 
         return user
@@ -612,12 +606,12 @@ class _LDAPUser:
                     "user does not satisfy AUTH_LDAP_NO_NEW_USERS"
                 )
 
-            logger.debug("Creating Django user {}".format(username))
+            logger.debug("Creating Django user %s", username)
             self._user.set_unusable_password()
             save_user = True
 
         if should_populate:
-            logger.debug("Populating Django user {}".format(username))
+            logger.debug("Populating Django user %s", username)
             self._populate_user()
             save_user = True
 
@@ -648,9 +642,7 @@ class _LDAPUser:
                 # TypeError occurs when self.attrs is None as we were unable to
                 # load this user's attributes.
                 logger.warning(
-                    "{} does not have a value for the attribute {}".format(
-                        self.dn, attr
-                    )
+                    "%s does not have a value for the attribute %s", self.dn, attr
                 )
             else:
                 setattr(self._user, field, value)
@@ -830,6 +822,7 @@ class _LDAPUser:
         the life of this object. If False, then the caller only wishes to test
         the credentials, after which the connection will be considered unbound.
         """
+        logger.debug("Binding as %s", bind_dn)
         self._get_connection().simple_bind_s(bind_dn, bind_password)
 
         self._connection_bound = sticky
@@ -925,11 +918,8 @@ class _LDAPUserGroups:
         if is_member is None:
             is_member = group_dn in self.get_group_dns()
 
-        logger.debug(
-            "{} is{}a member of {}".format(
-                self._ldap_user.dn, is_member and " " or " not ", group_dn
-            )
-        )
+        membership = "" if is_member else " not"
+        logger.debug(f"%s is{membership} a member of %s", self._ldap_user.dn, group_dn)
 
         return is_member
 
