@@ -144,15 +144,20 @@ class LDAPSearch:
 
         try:
             filterstr = self.filterstr % filterargs
+            logger.debug(
+                "Invoking search_s('%s', %s, '%s')", self.base_dn, self.scope, filterstr
+            )
             results = connection.search_s(
                 self.base_dn, self.scope, filterstr, self.attrlist
             )
         except ldap.LDAPError as e:
             results = []
             logger.error(
-                "search_s('{}', {}, '{}') raised {}".format(
-                    self.base_dn, self.scope, filterstr, pprint.pformat(e)
-                )
+                "search_s('%s', %s, '%s') raised %s",
+                self.base_dn,
+                self.scope,
+                filterstr,
+                pprint.pformat(e),
             )
 
         return self._process_results(results)
@@ -177,9 +182,11 @@ class LDAPSearch:
         except ldap.LDAPError as e:
             msgid = None
             logger.error(
-                "search('{}', {}, '{}') raised {}".format(
-                    self.base_dn, self.scope, filterstr, pprint.pformat(e)
-                )
+                "search('%s', %s, '%s') raised %s",
+                self.base_dn,
+                self.scope,
+                filterstr,
+                pprint.pformat(e),
             )
 
         return msgid
@@ -194,7 +201,7 @@ class LDAPSearch:
                 results = []
         except ldap.LDAPError as e:
             results = []
-            logger.error("result({}) raised {}".format(msgid, pprint.pformat(e)))
+            logger.error("result(%s) raised %s", msgid, pprint.pformat(e))
 
         return self._process_results(results)
 
@@ -234,13 +241,12 @@ class LDAPSearch:
 
         result_dns = [result[0] for result in results]
         logger.debug(
-            "search_s('{}', {}, '{}') returned {} objects: {}".format(
-                self.base_dn,
-                self.scope,
-                self.filterstr,
-                len(result_dns),
-                "; ".join(result_dns),
-            )
+            "search_s('%s', %s, '%s') returned %d objects: %s",
+            self.base_dn,
+            self.scope,
+            self.filterstr,
+            len(result_dns),
+            "; ".join(result_dns),
         )
 
         return results
@@ -392,6 +398,13 @@ class LDAPGroupType:
         return name
 
 
+ALLOWED_LDAP_MEMBERSHIP_EXCEPTIONS = (
+    ldap.UNDEFINED_TYPE,  # Attribute does not exist in LDAP schema.
+    ldap.NO_SUCH_ATTRIBUTE,  # Attribute does not exist in the entry.
+    ldap.NO_SUCH_OBJECT,  # Group does not exist.
+)
+
+
 class PosixGroupType(LDAPGroupType):
     """
     An LDAPGroupType subclass that handles groups of class posixGroup.
@@ -437,7 +450,7 @@ class PosixGroupType(LDAPGroupType):
                 is_member = ldap_user.connection.compare_s(
                     group_dn, "memberUid", user_uid.encode()
                 )
-            except (ldap.UNDEFINED_TYPE, ldap.NO_SUCH_ATTRIBUTE):
+            except ALLOWED_LDAP_MEMBERSHIP_EXCEPTIONS:
                 is_member = False
 
             if not is_member:
@@ -446,7 +459,7 @@ class PosixGroupType(LDAPGroupType):
                     is_member = ldap_user.connection.compare_s(
                         group_dn, "gidNumber", user_gid.encode()
                     )
-                except (ldap.UNDEFINED_TYPE, ldap.NO_SUCH_ATTRIBUTE):
+                except ALLOWED_LDAP_MEMBERSHIP_EXCEPTIONS:
                     is_member = False
         except (KeyError, IndexError):
             is_member = False
@@ -482,7 +495,7 @@ class MemberDNGroupType(LDAPGroupType):
             result = ldap_user.connection.compare_s(
                 group_dn, self.member_attr, ldap_user.dn.encode()
             )
-        except (ldap.UNDEFINED_TYPE, ldap.NO_SUCH_ATTRIBUTE):
+        except ALLOWED_LDAP_MEMBERSHIP_EXCEPTIONS:
             result = 0
 
         return result
